@@ -5,22 +5,22 @@
 # Copyright (c) 2021 Samuel Gratzl <sam@sgratzl.com>
 #
 
-toyset_1 = as.data.frame(read.delim(
+toyset_1 <- as.data.frame(read.delim(
   file = testthat::test_path("data", "toyset_1.tsv.gz"),
   sep = "\t"
-))[,1:6]
+))[, 1:6]
 
 
 test_that("toyset1 distinct", {
   expect_equal(nrow(toyset_1), 24152)
   expect_equal(ncol(toyset_1), 6)
 
-  u = upsetjs_mock() %>% fromDataFrame(toyset_1, c_type = 'distinctIntersection')
+  u <- upsetjs_mock() %>% fromDataFrame(toyset_1, c_type = "distinctIntersection")
 
-  sets = u %>% getSets()
+  sets <- u %>% getSets()
   expect_equal(length(sets), 6)
 
-  combinations = u %>% getCombinations()
+  combinations <- u %>% getCombinations()
   expect_equal(length(combinations), 37)
 })
 
@@ -28,11 +28,11 @@ test_that("toyset1 intersection", {
   expect_equal(nrow(toyset_1), 24152)
   expect_equal(ncol(toyset_1), 6)
 
-  u = upsetjs_mock() %>% fromDataFrame(toyset_1, c_type = 'intersection')
+  u <- upsetjs_mock() %>% fromDataFrame(toyset_1, c_type = "intersection")
 
-  sets = u %>% getSets()
+  sets <- u %>% getSets()
   expect_equal(length(sets), 6)
 
-  combinations = u %>% getCombinations()
+  combinations <- u %>% getCombinations()
   expect_equal(length(combinations), 63)
 })
